==> ejc-report-api-3.0.0-20201109.092104-15-sources.jar: com/ejianc/foundation/report/vo/ColumnVO.java <==
package com.ejianc.foundation.report.vo;

import com.ejianc.framework.skeleton.template.BaseTreeVO;

public class ColumnVO extends BaseTreeVO<ColumnVO> {

	private static final long serialVersionUID = -2517697654053683081L;

	private Long tableId; // 对应的数据表名

	private String type; // 字段类型（string，number）

	private String property; // 属性

	private String columnName; // 列名

	private String formula; // 计算公式

	private Integer searchFlag; // 是否固定

	private Integer visible; // 是否显示

	private Integer sequence; // 排序

	private Long parentId; // 父Id

	//数据格式话js函数
	private String formatter;

	public Long getTableId() {
		return tableId;
	}

	public void setTableId(Long tableId) {
		this.tableId = tableId;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public String getProperty() {
		return property;
	}

	public void setProperty(String property) {
		this.property = property;
	}

	public String getColumnName() {
		return columnName;
	}

	public void setColumnName(String columnName) {
		this.columnName = columnName;
	}

	public String getFormula() {
		return formula;
	}

	public void setFormula(String formula) {
		this.formula = formula;
	}

	public Integer getSearchFlag() {
		return searchFlag;
	}

	public void setSearchFlag(Integer searchFlag) {
		this.searchFlag = searchFlag;
	}

	public Integer getVisible() {
		return visible;
	}

	public void setVisible(Integer visible) {
		this.visible = visible;
	}

	public Integer getSequence() {
		return sequence;
	}

	public void setSequence(Integer sequence) {
		this.sequence = sequence;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public String getFormatter() {
		return formatter;
	}

	public void setFormatter(String formatter) {
		this.formatter = formatter;
	}
}

==> ejc-report-api-3.0.0-20201208.083445-61-sources.jar: com/ejianc/foundation/report/vo/ColumnVO.java <==
package com.ejianc.foundation.report.vo;

import com.ejianc.framework.skeleton.template.BaseTreeVO;

public class ColumnVO extends BaseTreeVO<ColumnVO> {

	private static final long serialVersionUID = -2517697654053683081L;

	private Long tableId; // 对应的数据表名

	private String type; // 字段类型（string，number）

	private String property; // 属性

	private String columnName; // 列名

	private String formula; // 计算公式

	private Integer searchFlag; // 是否固定

	private Integer visible; // 是否显示

	private Integer sequence; // 排序

	private Long parentId; // 父Id

	//数据格式话js函数
	private String formatter;

	//是否开启数据汇总
	private Boolean enableSummarize;

	//导出格式化
	private String exportFormat;

	//列对齐方式
	private String alignType;

	/**
	 * 字段后缀（字段展示时拼接到字段后面）
	 */
	private String suffixStr;

	public String getSuffixStr() {
		return suffixStr;
	}

	public void setSuffixStr(String suffixStr) {
		this.suffixStr = suffixStr;
	}

	public String getAlignType() {
		return alignType;
	}

	public void setAlignType(String alignType) {
		this.alignType = alignType;
	}

	public Boolean getEnableSummarize() {
		return enableSummarize;
	}

	public void setEnableSummarize(Boolean enableSummarize) {
		this.enableSummarize = enableSummarize;
	}

	public Long getTableId() {
		return tableId;
	}

	public void setTableId(Long tableId) {
		this.tableId = tableId;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public String getProperty() {
		return property;
	}

	public void setProperty(String property) {
		this.property = property;
	}

	public String getColumnName() {
		return columnName;
	}

	public void setColumnName(String columnName) {
		this.columnName = columnName;
	}

	public String getFormula() {
		return formula;
	}

	public void setFormula(String formula) {
		this.formula = formula;
	}

	public Integer getSearchFlag() {
		return searchFlag;
	}

	public void setSearchFlag(Integer searchFlag) {
		this.searchFlag = searchFlag;
	}

	public Integer getVisible() {
		return visible;
	}

	public void setVisible(Integer visible) {
		this.visible = visible;
	}

	public Integer getSequence() {
		return sequence;
	}

	public void setSequence(Integer sequence) {
		this.sequence = sequence;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public String getFormatter() {
		return formatter;
	}

	public void setFormatter(String formatter) {
		this.formatter = formatter;
	}

	public String getExportFormat() {
		return exportFormat;
	}

	public void setExportFormat(String exportFormat) {
		this.exportFormat = exportFormat;
	}
}
